=== modified file 'libsyncdaemon/Makefile.am'
--- libsyncdaemon/Makefile.am	2010-06-02 08:52:05 +0000
+++ libsyncdaemon/Makefile.am	2010-06-04 10:09:15 +0000
@@ -19,6 +19,7 @@
 syncdaemoninclude_HEADERS =		\
 	syncdaemon-daemon.h		\
 	syncdaemon-config-interface.h	\
+	syncdaemon-events-interface.h	\
 	syncdaemon-interface.h
 
 libsyncdaemon_1_0_la_SOURCES =		\
@@ -26,6 +27,7 @@
 	$(syncdaemoninclude_HEADERS)	\
 	syncdaemon-daemon.c		\
 	syncdaemon-config-interface.c	\
+	syncdaemon-events-interface.c	\
 	syncdaemon-interface.c
 
 libsyncdaemon_1_0_la_LIBADD  =	\

=== modified file 'libsyncdaemon/syncdaemon-daemon.c'
--- libsyncdaemon/syncdaemon-daemon.c	2010-06-04 09:10:23 +0000
+++ libsyncdaemon/syncdaemon-daemon.c	2010-06-04 10:09:15 +0000
@@ -28,6 +28,7 @@
 #endif
 #include "syncdaemon-daemon.h"
 #include "syncdaemon-config-interface.h"
+#include "syncdaemon-events-interface.h"
 #include "syncdaemon-marshal.h"
 
 G_DEFINE_TYPE(SyncdaemonDaemon, syncdaemon_daemon, G_TYPE_OBJECT)
@@ -386,6 +387,17 @@
 }
 
 /**
+ * syncdaemon_daemon_get_events_interface:
+ */
+SyncdaemonInterface *
+syncdaemon_daemon_get_events_interface (SyncdaemonDaemon *daemon)
+{
+	g_return_val_if_fail (SYNCDAEMON_IS_DAEMON (daemon), NULL);
+
+	return get_interface (daemon, "/events", syncdaemon_events_interface_new);
+}
+
+/**
  * syncdaemon_daemon_get_status_interface:
  */
 SyncdaemonInterface *

=== modified file 'libsyncdaemon/syncdaemon-daemon.h'
--- libsyncdaemon/syncdaemon-daemon.h	2010-06-04 09:10:23 +0000
+++ libsyncdaemon/syncdaemon-daemon.h	2010-06-04 10:09:15 +0000
@@ -48,6 +48,7 @@
 	void (* connected) (SyncdaemonDaemon *daemon);
 	void (* disconnected) (SyncdaemonDaemon *daemon);
 
+	void (* event) (SyncdaemonDaemon *daemon, GHashTable *event_dict);
 	void (* error) (SyncdaemonDaemon *daemon, const gchar *signal, GHashTable *extra_args);
 } SyncdaemonDaemonClass;
 
@@ -60,6 +61,7 @@
 const gchar         *syncdaemon_daemon_get_root_dir (SyncdaemonDaemon *daemon);
 
 SyncdaemonInterface *syncdaemon_daemon_get_config_interface (SyncdaemonDaemon *daemon);
+SyncdaemonInterface *syncdaemon_daemon_get_events_interface (SyncdaemonDaemon *daemon);
 SyncdaemonInterface *syncdaemon_daemon_get_status_interface (SyncdaemonDaemon *daemon);
 
 G_END_DECLS

=== added file 'libsyncdaemon/syncdaemon-events-interface.c'
--- libsyncdaemon/syncdaemon-events-interface.c	1970-01-01 00:00:00 +0000
+++ libsyncdaemon/syncdaemon-events-interface.c	2010-06-04 10:09:15 +0000
@@ -0,0 +1,120 @@
+/*
+ * Syncdaemon API
+ *
+ * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
+ *
+ * Copyright 2010 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
+#include "config.h"
+#ifdef HAVE_GDBUS
+#else
+#include <dbus/dbus-glib.h>
+#endif
+#include "syncdaemon-events-interface.h"
+
+G_DEFINE_TYPE(SyncdaemonEventsInterface, syncdaemon_events_interface, SYNCDAEMON_TYPE_INTERFACE)
+
+struct _SyncdaemonEventsInterfacePrivate {
+	GObject *proxy;
+};
+
+static void
+syncdaemon_events_interface_finalize (GObject *object)
+{
+	SyncdaemonEventsInterface *interface = SYNCDAEMON_EVENTS_INTERFACE (object);
+
+	if (interface->priv != NULL) {
+		if (interface->priv->proxy != NULL)
+			g_object_unref (interface->priv->proxy);
+
+		g_free (interface->priv);
+	}
+
+	G_OBJECT_CLASS (syncdaemon_events_interface_parent_class)->finalize (object);
+}
+
+static void
+syncdaemon_events_interface_class_init (SyncdaemonEventsInterfaceClass *klass)
+{
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+	object_class->finalize = syncdaemon_events_interface_finalize;
+}
+
+static void
+event_cb (DBusGProxy *proxy, GHashTable *event_dict, gpointer user_data)
+{
+	SyncdaemonDaemon *daemon = NULL;
+	SyncdaemonEventsInterface *interface = SYNCDAEMON_EVENTS_INTERFACE (user_data);
+
+	g_object_get (G_OBJECT (interface), "daemon", &daemon, NULL);
+	if (daemon != NULL)
+		g_signal_emit_by_name (daemon, "event", event_dict);
+}
+
+static void
+syncdaemon_events_interface_init (SyncdaemonEventsInterface *interface)
+{
+	interface->priv = g_new0 (SyncdaemonEventsInterfacePrivate, 1);
+
+	/* Setup DBus proxy */
+	interface->priv->proxy = syncdaemon_interface_setup_proxy (SYNCDAEMON_INTERFACE (interface),
+								   "com.ubuntuone.Syncdaemon",
+								   "/events", "com.ubuntuone.Syncdaemon.Events");
+	if (interface->priv->proxy != NULL) {
+		dbus_g_proxy_add_signal (DBUS_G_PROXY (interface->priv->proxy), "Event",
+					 dbus_g_type_get_map ("GHashTable",
+							      G_TYPE_STRING,
+							      G_TYPE_STRING),
+					 G_TYPE_INVALID);
+		dbus_g_proxy_connect_signal (DBUS_G_PROXY (interface->priv->proxy), "Event",
+					     G_CALLBACK (event_cb), interface, NULL);
+	}
+}
+
+/**
+ * syncdaemon_events_interface_new:
+ */
+SyncdaemonEventsInterface *
+syncdaemon_events_interface_new (SyncdaemonDaemon *daemon)
+{
+	g_return_val_if_fail (SYNCDAEMON_IS_DAEMON (daemon), NULL);
+
+	return g_object_new (SYNCDAEMON_TYPE_EVENTS_INTERFACE, "daemon", daemon, NULL);
+}
+
+/**
+ * syncdaemon_events_interface_push_event:
+ */
+void
+syncdaemon_events_interface_push_event (SyncdaemonEventsInterface *interface,
+					const gchar *event_name,
+					const gchar **args)
+{
+	GError *error = NULL;
+
+	g_return_if_fail (SYNCDAEMON_IS_EVENTS_INTERFACE (interface));
+
+	if (!dbus_g_proxy_call (DBUS_G_PROXY (interface->priv->proxy), "push_event", &error,
+				G_TYPE_INVALID,
+				G_TYPE_STRING, event_name,
+				G_TYPE_STRV, args,
+				G_TYPE_INVALID)) {
+		g_warning ("Failled calling push_event: %s", error->message);
+		g_error_free (error->message);
+	}
+}

=== added file 'libsyncdaemon/syncdaemon-events-interface.h'
--- libsyncdaemon/syncdaemon-events-interface.h	1970-01-01 00:00:00 +0000
+++ libsyncdaemon/syncdaemon-events-interface.h	2010-06-04 10:09:15 +0000
@@ -0,0 +1,58 @@
+/*
+ * Syncdaemon API
+ *
+ * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
+ *
+ * Copyright 2010 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
+#ifndef __SYNCDAEMON_EVENTS_INTERFACE_H__
+#define __SYNCDAEMON_EVENTS_INTERFACE_H__
+
+#include "syncdaemon-daemon.h"
+#include "syncdaemon-interface.h"
+
+G_BEGIN_DECLS
+
+#define SYNCDAEMON_TYPE_EVENTS_INTERFACE                (syncdaemon_events_interface_get_type ())
+#define SYNCDAEMON_EVENTS_INTERFACE(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), SYNCDAEMON_TYPE_EVENTS_INTERFACE, SyncdaemonEventsInterface))
+#define SYNCDAEMON_IS_EVENTS_INTERFACE(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SYNCDAEMON_TYPE_EVENTS_INTERFACE))
+#define SYNCDAEMON_EVENTS_INTERFACE_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), SYNCDAEMON_TYPE_EVENTS_INTERFACE, SyncdaemonEventsInterfaceClass))
+#define SYNCDAEMON_IS_EVENTS_INTERFACE_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), SYNCDAEMON_TYPE_EVENTS_INTERFACE))
+#define SYNCDAEMON_EVENTS_INTERFACE_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), SYNCDAEMON_TYPE_EVENTS_INTERFACE, SyncdaemonEventsInterfaceClass))
+
+typedef struct _SyncdaemonEventsInterfacePrivate SyncdaemonEventsInterfacePrivate;
+
+typedef struct {
+	SyncdaemonInterface parent;
+	SyncdaemonEventsInterfacePrivate *priv;
+} SyncdaemonEventsInterface;
+
+typedef struct {
+	SyncdaemonInterfaceClass parent_class;
+} SyncdaemonEventsInterfaceClass;
+
+GType                      syncdaemon_events_interface_get_type (void);
+
+SyncdaemonEventsInterface *syncdaemon_events_interface_new (SyncdaemonDaemon *daemon);
+
+void                       syncdaemon_events_interface_push_event (SyncdaemonEventsInterface *interface,
+								   const gchar *event_name,
+								   const gchar **args);
+
+G_END_DECLS
+
+#endif

